@@ -34,19 +34,21 @@ bool pg_type::consistent(sqltype *rvalue)
   case 'e': /* enum */
     return this == t;
     
-  case 'p': /* pseudo type */
-    if (name == "anyarray") {
+  case 'p': /* pseudo type: accept any concrete matching type */
+    if (name == "anyarray" || name == "anycompatiblearray") {
       return t->typelem_ != InvalidOid;
-    } else if (name == "anynonarray") {
+    } else if (name == "anynonarray" || name == "anycompatiblenonarray") {
       return t->typelem_ == InvalidOid;
     } else if(name == "anyenum") {
       return t->typtype_ == 'e';
-    } else if (name == "any") {
-      return true;
+    } else if (name == "\"any\"" || name == "anycompatible") { /* as quoted by quote_ident() */
+      return t->typtype_ != 'p'; /* any non-pseudo type */
     } else if (name == "anyelement") {
       return t->typelem_ == InvalidOid;
-    } else if (name == "anyrange") {
+    } else if (name == "anyrange" || name == "anycompatiblerange") {
       return t->typtype_ == 'r';
+    } else if (name == "anymultirange" || name == "anycompatiblemultirange") {
+      return t->typtype_ == 'm';
     } else if (name == "record") {
       return t->typtype_ == 'c';
     } else if (name == "cstring") {
@@ -112,7 +114,9 @@ schema_pqxx::schema_pqxx(std::string &conninfo, bool no_catalog) : c(conninfo)
 
   cerr << "Loading types...";
 
-  r = w.exec("select quote_ident(typname), oid, typdelim, typrelid, typelem, typarray, typtype "
+  r = w.exec("select case typnamespace when 'pg_catalog'::regnamespace then quote_ident(typname) "
+	     "else format('%I.%I', typnamespace::regnamespace, typname) end, "
+	     "oid, typdelim, typrelid, typelem, typarray, typtype "
 	     "from pg_type ");
   
   for (auto row = r.begin(); row != r.end(); ++row) {
