@@ -8,4 +8,9 @@ sqltype * sqltype::get(string n)
     return typemap[n];
   else
     return typemap[n] = new sqltype(n);
-};
+}
+
+bool sqltype::consistent(struct sqltype *rvalue)
+{
+  return this == rvalue;
+}
